@@ -3,9 +3,9 @@ import requests
 
 
 def upload(filename, file):
-
     headers = {
-        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/91.0.4472.124 Safari/537.36"
+        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/91.0.4472.124 Safari/537.36",
+        "Referer": "pyscord-storage",
     }
 
     # upload file from URL
@@ -19,9 +19,8 @@ def upload(filename, file):
 
         return {"status": response.status_code, "data": json.loads(response.text)}
 
-    # upload from file
     else:
-
+        # upload from file
         response = requests.post(
             "https://discord-storage.animemoe.us/upload-from-file/",
             headers=headers,
